@@ -82,6 +82,11 @@ def main():
         action="store_true",
         help="don't use cookies in ~/.cache/gdown/cookies.json",
     )
+    parser.add_argument(
+        "--no-check-certificate",
+        action="store_true",
+        help="don't check the server's TLS certificate",
+    )
 
     args = parser.parse_args()
 
@@ -103,6 +108,7 @@ def main():
         proxy=args.proxy,
         speed=args.speed,
         use_cookies=not args.no_cookies,
+        verify=not args.no_check_certificate,
     )
 
     if filename is None:
